==> cms-db_v0.7.9.tar.gz: admin/guestbook.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
?>
<?php
if (isset($_GET['deleted'])) {
	echo '<p class="hint">'.locale('desc_deleted',true).'</p>';
}
?>
<p>
	<?php locale('desc_delete') ?>
</p>
<p>
<?php
if (!isset($article)) {
	$gbfile = '../data/gbfile.csv';
} else {
	$gbfile = '../data/blog/articles/'.$article.'/comments';
}
if (file_exists($gbfile)) {
	echo '<hr style="background-color:#000000;color:#000000;border:#000000;height:2px">';
	$handle = fopen ($gbfile, 'r');
	while ( ($data = fgetcsv ($handle, 1000, ",")) !== FALSE ) {
		$entries[] = $data;
	}
	fclose($handle);
	if ($entries) {
		$entries = array_reverse($entries, true);
		foreach($entries AS $data) {
			$gb_name = $data[0];
			$gb_email = $data[1];
			$gb_text = $data[2];
			if (strpos($data[3], ':') === false) {
				$gb_time = date('H:i:s', $data[3]);
				$gb_date = date('d.m.Y', $data[3]);
				$gb_website = $data[4];
			} else {
				$gb_time = $data[3];
				$gb_date = $data[4];
				$gb_website = '';
			}

			echo '<form action="delgb.php?'.SID.'" method="post" style="float: right; background-color: #fff">
				<input type="hidden" name="name" value="'.htmlspecialchars($data[0]).'" />
				<input type="hidden" name="time" value="'.htmlspecialchars($data[3]).'" />';
			if (isset($article)) {
				echo '<input type="hidden" name="article" value="'.$article.'" />';
			}
			echo '<input type="submit" value="'.locale('link_delete',true).'" />
				</form>';
			echo '<b>'.locale('label_name',true).'</b> '.$gb_name;
			if ($gb_email!='') {
				echo ' <b>'.locale('label_email',true).'</b> <a class="nonewtab" href="mailto:'.$gb_email.'">'.$gb_email.'</a>';
			}
			if ($gb_website != '') {
				if (substr($gb_website, 0, 4) != 'http') {
					$gb_website = 'http://'.$gb_website;
				}
				echo ' <b>'.locale('label_website',true).'</b> <a class="nonewtab" href="'.$gb_website.'">'.$gb_website.'</a>';
			}
			echo '<br />';
			echo '<b>'.locale('label_time',true).'</b> '.$gb_time.' ';
			echo '<b>'.locale('label_date',true).'</b> '.$gb_date;
			echo '<hr style="background-color:#000000;color:#000000;border:#000000;height: 1px">';
			echo $gb_text.'<hr style="background-color:#000000;color:#000000;border:#000000;height: 2px">';
		}
	} else {
		locale('desc_no-entries');
	}
} else {
	locale('desc_no-entries');
}
?>
</p>

==> cms-db_v0.8.1.tar.gz: admin/guestbook.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

?>
<?php
if (isset($_GET['deleted'])) {
	echo '<p class="hint">'.locale('desc_deleted',true).'</p>';
}
?>
<p>
	<?php locale('desc_delete') ?>
</p>
<p>
<?php
if (!isset($article)) {
	$gbfile = '../data/gbfile.csv';
} else {
	$gbfile = '../data/blog/articles/'.$article.'/comments';
}
if (file_exists($gbfile)) {
	echo '<hr style="background-color:#000000;color:#000000;border:#000000;height:2px">';
	$handle = fopen ($gbfile, 'r');
	while ( ($data = fgetcsv ($handle, 1000, ",")) !== FALSE ) {
		$entries[] = $data;
	}
	fclose($handle);
	if ($entries) {
		$entries = array_reverse($entries, true);
		foreach($entries AS $data) {
			$gb_name = $data[0];
			$gb_email = $data[1];
			$gb_text = $data[2];
			if (strpos($data[3], ':') === false) {
				$gb_time = date('H:i:s', $data[3]);
				$gb_date = date('d.m.Y', $data[3]);
				$gb_website = $data[4];
			} else {
				$gb_time = $data[3];
				$gb_date = $data[4];
				$gb_website = '';
			}

			echo '<form action="delgb.php?'.SID.csrf_protection_get_html_ret().'" method="post" style="float: right; background-color: #fff">
				<input type="hidden" name="name" value="'.htmlspecialchars($data[0]).'" />
				<input type="hidden" name="time" value="'.htmlspecialchars($data[3]).'" />';
			if (isset($article)) {
				echo '<input type="hidden" name="article" value="'.$article.'" />';
			}
			echo '<input type="submit" value="'.locale('link_delete',true).'" />
				</form>';
			echo '<b>'.locale('label_name',true).'</b> '.$gb_name;
			if ($gb_email!='') {
				echo ' <b>'.locale('label_email',true).'</b> <a class="nonewtab" href="mailto:'.$gb_email.'">'.$gb_email.'</a>';
			}
			if ($gb_website != '') {
				if (substr($gb_website, 0, 4) != 'http') {
					$gb_website = 'http://'.$gb_website;
				}
				echo ' <b>'.locale('label_website',true).'</b> <a class="nonewtab" href="'.$gb_website.'">'.$gb_website.'</a>';
			}
			echo '<br />';
			echo '<b>'.locale('label_time',true).'</b> '.$gb_time.' ';
			echo '<b>'.locale('label_date',true).'</b> '.$gb_date;
			echo '<hr style="background-color:#000000;color:#000000;border:#000000;height: 1px">';
			echo $gb_text.'<hr style="background-color:#000000;color:#000000;border:#000000;height: 2px">';
		}
	} else {
		locale('desc_no-entries');
	}
} else {
	locale('desc_no-entries');
}
?>
</p>
